
// LeapDoodle.java
// Andrew Davison, July 2013, ad@fivedots.coe.psu.ac.th

/* Create a drawing canvas (in DoodlePanel) where the user can 
   move a dot, draw dots, un-draw dots (i.e. delete them), and change
   the drawing color (which starts as blue).

  These actions are controlled via the Leap controller 
  (https://www.leapmotion.com/), using:
        * one finger == move the dot
        * two fingers == draw dots on the canvas as the dot moves
        * three fingers == un-draw dots
 
  If two hands are detected, then the dot stops moving, and if a
  circling finger gesture is detected for the *left* hand then the
  color of the current dot cycles through a range of colors. 
  Counter-clockwise circling reverses the cycling of the colors.

  The first dot always starts at the center of the screen, and movement
  is relative to the region of the screen that the hand is pointing towards.
*/

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


public class LeapDoodle extends JFrame 
{
  private DoodlePanel dp;   // drawing area 


  public LeapDoodle()
  {
    super("Leap Doodle");
	Container c = getContentPane();
    dp = new DoodlePanel();
	c.add(dp);
    
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    addWindowListener( new WindowAdapter() {
      public void windowClosing(WindowEvent e)
      { dp.stopListening();
        System.exit(0);
      }
    });
    
    pack();  
    setResizable(false);
    setLocationRelativeTo(null);  // center the window 
    setVisible(true);
  }  // end of LeapDoodle()


  // ---------------------------------------------------

  public static void main(String args[])
  {  new LeapDoodle(); }

} // end of LeapDoodle

