
// LeapModel3D.java
// Andrew Davison, July 2013, ad@fivedots.coe.psu.ac.th

/* A Java 3D checkboard world with a 3D robot sprite, which
   can move about on the XZ plane, rotate around the
   y-axis, but can not move off the checkboard.

  The translations are controlled via the Leap controller 
  (https://www.leapmotion.com/), using a hand's position
  relative to the leap controller, using only the x- and z-
  values.
  
  The rotation is controlled by a circling finger gesture, 
  which depending on its direction will
  turn the robot left or right around the y-axis.

  It is possible to combine translations and rotations at the same
  time to have the robot move through an arc for example.

  The 3D viewpoint (the camera) can be moved using mouse operations.
  Camera moves are independent of the model, and are implemented 
  using Java 3D.

  Usage:     > run LeapModel3D             // loads the robot by default
             > run LeapModel hand.obj

  =======================
  Most of the Java 3D code in this application is taken from the
  3D Sprites example in http://fivedots.coe.psu.ac.th/~ad/jg/ch10/.
  That URL contains a PDF file explaining the code in detail.
*/

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


public class LeapModel3D extends JFrame
{

  private static final String MODEL_FNM = "coolrobo.3ds";   
         // the robot model, stored in the models/ subdirectory
         /* change this to "hand.obj" to move a hand model around the
            checkerboard */


  public LeapModel3D(String fnm) 
  {
    super("Leap Model 3D using " + fnm);

    Container c = getContentPane();
    c.setLayout( new BorderLayout() );
    WrapLeapModel3D w3d = new WrapLeapModel3D(fnm);
    c.add(w3d, BorderLayout.CENTER);

    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    pack();
    setResizable(false);    // fixed size display
    setLocationRelativeTo(null);
    setVisible(true);
  } // end of LeapModel3D()


// -----------------------------------------

  public static void main(String[] args)
  { 
    if (args.length == 1)
      new LeapModel3D(args[0]);
    else
      new LeapModel3D(MODEL_FNM); 
  }

} // end of LeapModel3D class



